Module beamlit.models.update_workspace_user_role_body
=====================================================

Classes
-------

`UpdateWorkspaceUserRoleBody(role: str)`
:   Attributes:
        role (str): The new role to assign to the user
    
    Method generated by attrs for class UpdateWorkspaceUserRoleBody.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `role: str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :